@@ -1,5 +1,9 @@
 
 import os
+import sys
+if sys.platform == 'win32':
+  from .windows import add_jvm_dll_directory_to_path
+  add_jvm_dll_directory_to_path('server')
 from . import _orekit
 
 __module_dir__ = os.path.abspath(os.path.dirname(__file__))
@@ -17,8 +21,8 @@ class InvalidArgsError(Exception):
 
 _orekit._set_exception_types(JavaError, InvalidArgsError)
 
-VERSION = "11.0.2"
-CLASSPATH = [os.path.join(__module_dir__, "orekit-11.0.2.jar"), os.path.join(__module_dir__, "hipparchus-core-2.0.jar"), os.path.join(__module_dir__, "hipparchus-fitting-2.0.jar"), os.path.join(__module_dir__, "hipparchus-filtering-2.0.jar"), os.path.join(__module_dir__, "hipparchus-geometry-2.0.jar"), os.path.join(__module_dir__, "hipparchus-ode-2.0.jar"), os.path.join(__module_dir__, "hipparchus-optim-2.0.jar"), os.path.join(__module_dir__, "hipparchus-stat-2.0.jar")]
+VERSION = "11.2"
+CLASSPATH = [os.path.join(__module_dir__, "orekit-11.2.jar"), os.path.join(__module_dir__, "hipparchus-core-2.1.jar"), os.path.join(__module_dir__, "hipparchus-fitting-2.1.jar"), os.path.join(__module_dir__, "hipparchus-filtering-2.1.jar"), os.path.join(__module_dir__, "hipparchus-geometry-2.1.jar"), os.path.join(__module_dir__, "hipparchus-ode-2.1.jar"), os.path.join(__module_dir__, "hipparchus-optim-2.1.jar"), os.path.join(__module_dir__, "hipparchus-stat-2.1.jar")]
 CLASSPATH = os.pathsep.join(CLASSPATH)
 _orekit.CLASSPATH = CLASSPATH
 _orekit._set_function_self(_orekit.initVM, _orekit)
